# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_reservation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!gcp/gcp_compute_reservation.proto\x12#oak9.tython.gcp.compute_reservation\x1a\x13shared/shared.proto\"M\n+ComputeReservationXShareSettingsXProjectMap\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x9d\x01\n ComputeReservationXShareSettings\x12\x12\n\nshare_type\x18\x01 \x01(\t\x12\x65\n\x0bproject_map\x18\x02 \x03(\x0b\x32P.oak9.tython.gcp.compute_reservation.ComputeReservationXShareSettingsXProjectMap\"\x82\x01\nKComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators\x12\x19\n\x11\x61\x63\x63\x65lerator_count\x18\x01 \x01(\x01\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x02 \x01(\t\"n\nCComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds\x12\x14\n\x0c\x64isk_size_gb\x18\x01 \x01(\x01\x12\x11\n\tinterface\x18\x02 \x01(\t\"\xf8\x02\n9ComputeReservationXSpecificReservationXInstanceProperties\x12\x14\n\x0cmachine_type\x18\x01 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x02 \x01(\t\x12\x8c\x01\n\x12guest_accelerators\x18\x03 \x03(\x0b\x32p.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservationXInstancePropertiesXGuestAccelerators\x12|\n\nlocal_ssds\x18\x04 \x03(\x0b\x32h.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservationXInstancePropertiesXLocalSsds\"\xca\x01\n&ComputeReservationXSpecificReservation\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x14\n\x0cin_use_count\x18\x02 \x01(\x01\x12{\n\x13instance_properties\x18\x03 \x01(\x0b\x32^.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservationXInstanceProperties\"M\n\x1b\x43omputeReservationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb3\x04\n\x12\x43omputeReservation\x12\x12\n\ncommitment\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12%\n\x1dspecific_reservation_required\x18\x08 \x01(\x08\x12\x0e\n\x06status\x18\t \x01(\t\x12\x0c\n\x04zone\x18\n \x01(\t\x12]\n\x0eshare_settings\x18\x0b \x01(\x0b\x32\x45.oak9.tython.gcp.compute_reservation.ComputeReservationXShareSettings\x12i\n\x14specific_reservation\x18\x0c \x01(\x0b\x32K.oak9.tython.gcp.compute_reservation.ComputeReservationXSpecificReservation\x12R\n\x08timeouts\x18\r \x01(\x0b\x32@.oak9.tython.gcp.compute_reservation.ComputeReservationXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_reservation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTERESERVATIONXSHARESETTINGSXPROJECTMAP._serialized_start=95
  _COMPUTERESERVATIONXSHARESETTINGSXPROJECTMAP._serialized_end=172
  _COMPUTERESERVATIONXSHARESETTINGS._serialized_start=175
  _COMPUTERESERVATIONXSHARESETTINGS._serialized_end=332
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXGUESTACCELERATORS._serialized_start=335
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXGUESTACCELERATORS._serialized_end=465
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXLOCALSSDS._serialized_start=467
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIESXLOCALSSDS._serialized_end=577
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIES._serialized_start=580
  _COMPUTERESERVATIONXSPECIFICRESERVATIONXINSTANCEPROPERTIES._serialized_end=956
  _COMPUTERESERVATIONXSPECIFICRESERVATION._serialized_start=959
  _COMPUTERESERVATIONXSPECIFICRESERVATION._serialized_end=1161
  _COMPUTERESERVATIONXTIMEOUTS._serialized_start=1163
  _COMPUTERESERVATIONXTIMEOUTS._serialized_end=1240
  _COMPUTERESERVATION._serialized_start=1243
  _COMPUTERESERVATION._serialized_end=1806
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_dynamodb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_dynamodb.proto\x12\x18oak9.tython.aws.dynamodb\x1a\x13shared/shared.proto\"\x83\x01\n\x18TableAttributeDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\"\x97\x05\n\x08\x44ynamoDB\x12V\n\x1atable_attribute_definition\x18\x01 \x03(\x0b\x32\x32.oak9.tython.aws.dynamodb.TableAttributeDefinition\x12Y\n\x1ctable_global_secondary_index\x18\x02 \x03(\x0b\x32\x33.oak9.tython.aws.dynamodb.TableGlobalSecondaryIndex\x12W\n\x1btable_local_secondary_index\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.dynamodb.TableLocalSecondaryIndex\x12s\n*table_point_in_time_recovery_specification\x18\x04 \x03(\x0b\x32?.oak9.tython.aws.dynamodb.TablePointInTimeRecoverySpecification\x12P\n\x17table_sse_specification\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.dynamodb.TableSSESpecification\x12V\n\x1atable_stream_specification\x18\x06 \x03(\x0b\x32\x32.oak9.tython.aws.dynamodb.TableStreamSpecification\x12`\n table_time_to_live_specification\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.dynamodb.TableTimeToLiveSpecification\"s\n\x0eTableKeySchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x10\n\x08key_type\x18\x03 \x01(\t\"\x7f\n\x0fTableProjection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12non_key_attributes\x18\x02 \x03(\t\x12\x17\n\x0fprojection_type\x18\x03 \x01(\t\"\x90\x01\n\x1aTableProvisionedThroughput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13read_capacity_units\x18\x02 \x01(\x05\x12\x1c\n\x14write_capacity_units\x18\x03 \x01(\x05\"\xbb\x02\n\x19TableGlobalSecondaryIndex\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12<\n\nkey_schema\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.dynamodb.TableKeySchema\x12=\n\nprojection\x18\x04 \x01(\x0b\x32).oak9.tython.aws.dynamodb.TableProjection\x12T\n\x16provisioned_throughput\x18\x05 \x01(\x0b\x32\x34.oak9.tython.aws.dynamodb.TableProvisionedThroughput\"\xe4\x01\n\x18TableLocalSecondaryIndex\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12<\n\nkey_schema\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.dynamodb.TableKeySchema\x12=\n\nprojection\x18\x04 \x01(\x0b\x32).oak9.tython.aws.dynamodb.TableProjection\"\x88\x01\n%TablePointInTimeRecoverySpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1epoint_in_time_recovery_enabled\x18\x02 \x01(\x08\"\x92\x01\n\x15TableSSESpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11kms_master_key_id\x18\x02 \x01(\t\x12\x13\n\x0bsse_enabled\x18\x03 \x01(\x08\x12\x10\n\x08sse_type\x18\x04 \x01(\t\"m\n\x18TableStreamSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10stream_view_type\x18\x02 \x01(\t\"\x80\x01\n\x1cTableTimeToLiveSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_dynamodb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TABLEATTRIBUTEDEFINITION._serialized_start=74
  _TABLEATTRIBUTEDEFINITION._serialized_end=205
  _DYNAMODB._serialized_start=208
  _DYNAMODB._serialized_end=871
  _TABLEKEYSCHEMA._serialized_start=873
  _TABLEKEYSCHEMA._serialized_end=988
  _TABLEPROJECTION._serialized_start=990
  _TABLEPROJECTION._serialized_end=1117
  _TABLEPROVISIONEDTHROUGHPUT._serialized_start=1120
  _TABLEPROVISIONEDTHROUGHPUT._serialized_end=1264
  _TABLEGLOBALSECONDARYINDEX._serialized_start=1267
  _TABLEGLOBALSECONDARYINDEX._serialized_end=1582
  _TABLELOCALSECONDARYINDEX._serialized_start=1585
  _TABLELOCALSECONDARYINDEX._serialized_end=1813
  _TABLEPOINTINTIMERECOVERYSPECIFICATION._serialized_start=1816
  _TABLEPOINTINTIMERECOVERYSPECIFICATION._serialized_end=1952
  _TABLESSESPECIFICATION._serialized_start=1955
  _TABLESSESPECIFICATION._serialized_end=2101
  _TABLESTREAMSPECIFICATION._serialized_start=2103
  _TABLESTREAMSPECIFICATION._serialized_end=2212
  _TABLETIMETOLIVESPECIFICATION._serialized_start=2215
  _TABLETIMETOLIVESPECIFICATION._serialized_end=2343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_amazonmq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_amazonmq.proto\x12\x18oak9.tython.aws.amazonmq\x1a\x13shared/shared.proto\"n\n\x15\x42rokerConfigurationId\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08revision\x18\x02 \x01(\x05\x12\n\n\x02id\x18\x03 \x01(\t\"\x8f\x01\n\x17\x42rokerMaintenanceWindow\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x61y_of_week\x18\x02 \x01(\t\x12\x13\n\x0btime_of_day\x18\x03 \x01(\t\x12\x11\n\ttime_zone\x18\x04 \x01(\t\"t\n\x15\x42rokerInterBrokerCred\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\xe9\x02\n\x14\x42rokerServerMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x16\n\x0euser_role_name\x18\x03 \x01(\t\x12\x1c\n\x14user_search_matching\x18\x04 \x01(\t\x12\x11\n\trole_name\x18\x05 \x01(\t\x12\x11\n\tuser_base\x18\x06 \x01(\t\x12\x1b\n\x13user_search_subtree\x18\x07 \x01(\x08\x12\x1c\n\x14role_search_matching\x18\x08 \x01(\t\x12 \n\x18service_account_username\x18\t \x01(\t\x12\x11\n\trole_base\x18\n \x01(\t\x12 \n\x18service_account_password\x18\x0b \x01(\t\x12\x1b\n\x13role_search_subtree\x18\x0c \x01(\x08\"\xe3\x01\n\x12\x42rokerLdapMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x12inter_broker_creds\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.amazonmq.BrokerInterBrokerCred\x12G\n\x0fserver_metadata\x18\x03 \x01(\x0b\x32..oak9.tython.aws.amazonmq.BrokerServerMetadata\"\x91\x01\n\nBrokerUser\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0e\n\x06groups\x18\x03 \x03(\t\x12\x16\n\x0e\x63onsole_access\x18\x04 \x01(\x08\x12\x10\n\x08password\x18\x05 \x01(\t\"h\n\rBrokerLogList\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x61udit\x18\x02 \x01(\x08\x12\x0f\n\x07general\x18\x03 \x01(\x08\"\xed\x02\n\x18\x42rokerLdapServerMetadata\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x16\n\x0euser_role_name\x18\x03 \x01(\t\x12\x1c\n\x14user_search_matching\x18\x04 \x01(\t\x12\x11\n\trole_name\x18\x05 \x01(\t\x12\x11\n\tuser_base\x18\x06 \x01(\t\x12\x1b\n\x13user_search_subtree\x18\x07 \x01(\x08\x12\x1c\n\x14role_search_matching\x18\x08 \x01(\t\x12 \n\x18service_account_username\x18\t \x01(\t\x12\x11\n\trole_base\x18\n \x01(\t\x12 \n\x18service_account_password\x18\x0b \x01(\t\x12\x1b\n\x13role_search_subtree\x18\x0c \x01(\x08\"\x81\x01\n\x17\x42rokerEncryptionOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nkms_key_id\x18\x02 \x01(\t\x12\x19\n\x11use_aws_owned_key\x18\x03 \x01(\x08\"f\n\x0f\x42rokerTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\x8a\x07\n\x06\x42roker\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fsecurity_groups\x18\x02 \x03(\t\x12\x14\n\x0cstorage_type\x18\x03 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x04 \x01(\t\x12\x46\n\rconfiguration\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.amazonmq.BrokerConfigurationId\x12\x1f\n\x17\x61uthentication_strategy\x18\x06 \x01(\t\x12X\n\x1dmaintenance_window_start_time\x18\x07 \x01(\x0b\x32\x31.oak9.tython.aws.amazonmq.BrokerMaintenanceWindow\x12\x43\n\rldap_metadata\x18\x08 \x01(\x0b\x32,.oak9.tython.aws.amazonmq.BrokerLdapMetadata\x12\x1a\n\x12host_instance_type\x18\t \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\n \x01(\x08\x12\x33\n\x05users\x18\x0b \x03(\x0b\x32$.oak9.tython.aws.amazonmq.BrokerUser\x12\x35\n\x04logs\x18\x0c \x01(\x0b\x32\'.oak9.tython.aws.amazonmq.BrokerLogList\x12\x12\n\nsubnet_ids\x18\r \x03(\t\x12\x13\n\x0b\x62roker_name\x18\x0e \x01(\t\x12P\n\x14ldap_server_metadata\x18\x0f \x01(\x0b\x32\x32.oak9.tython.aws.amazonmq.BrokerLdapServerMetadata\x12\x17\n\x0f\x64\x65ployment_mode\x18\x10 \x01(\t\x12\x13\n\x0b\x65ngine_type\x18\x11 \x01(\t\x12\x1b\n\x13publicly_accessible\x18\x12 \x01(\x08\x12M\n\x12\x65ncryption_options\x18\x13 \x01(\x0b\x32\x31.oak9.tython.aws.amazonmq.BrokerEncryptionOptions\x12\x37\n\x04tags\x18\x14 \x03(\x0b\x32).oak9.tython.aws.amazonmq.BrokerTagsEntry\"\xd3\x01\n\x08\x41mazonMQ\x12\x30\n\x06\x62roker\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.amazonmq.Broker\x12>\n\rconfiguration\x18\x02 \x03(\x0b\x32\'.oak9.tython.aws.amazonmq.Configuration\x12U\n\x19\x63onfiguration_association\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.amazonmq.ConfigurationAssociation\"m\n\x16\x43onfigurationTagsEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xe6\x01\n\rConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x65ngine_version\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x65ngine_type\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\x12>\n\x04tags\x18\x06 \x03(\x0b\x32\x30.oak9.tython.aws.amazonmq.ConfigurationTagsEntry\x12\x0c\n\x04name\x18\x07 \x01(\t\"\x80\x01\n\'ConfigurationAssociationConfigurationId\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08revision\x18\x02 \x01(\x05\x12\n\n\x02id\x18\x03 \x01(\t\"\xbd\x01\n\x18\x43onfigurationAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62roker\x18\x02 \x01(\t\x12X\n\rconfiguration\x18\x03 \x01(\x0b\x32\x41.oak9.tython.aws.amazonmq.ConfigurationAssociationConfigurationIdb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_amazonmq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BROKERCONFIGURATIONID._serialized_start=73
  _BROKERCONFIGURATIONID._serialized_end=183
  _BROKERMAINTENANCEWINDOW._serialized_start=186
  _BROKERMAINTENANCEWINDOW._serialized_end=329
  _BROKERINTERBROKERCRED._serialized_start=331
  _BROKERINTERBROKERCRED._serialized_end=447
  _BROKERSERVERMETADATA._serialized_start=450
  _BROKERSERVERMETADATA._serialized_end=811
  _BROKERLDAPMETADATA._serialized_start=814
  _BROKERLDAPMETADATA._serialized_end=1041
  _BROKERUSER._serialized_start=1044
  _BROKERUSER._serialized_end=1189
  _BROKERLOGLIST._serialized_start=1191
  _BROKERLOGLIST._serialized_end=1295
  _BROKERLDAPSERVERMETADATA._serialized_start=1298
  _BROKERLDAPSERVERMETADATA._serialized_end=1663
  _BROKERENCRYPTIONOPTIONS._serialized_start=1666
  _BROKERENCRYPTIONOPTIONS._serialized_end=1795
  _BROKERTAGSENTRY._serialized_start=1797
  _BROKERTAGSENTRY._serialized_end=1899
  _BROKER._serialized_start=1902
  _BROKER._serialized_end=2808
  _AMAZONMQ._serialized_start=2811
  _AMAZONMQ._serialized_end=3022
  _CONFIGURATIONTAGSENTRY._serialized_start=3024
  _CONFIGURATIONTAGSENTRY._serialized_end=3133
  _CONFIGURATION._serialized_start=3136
  _CONFIGURATION._serialized_end=3366
  _CONFIGURATIONASSOCIATIONCONFIGURATIONID._serialized_start=3369
  _CONFIGURATIONASSOCIATIONCONFIGURATIONID._serialized_end=3497
  _CONFIGURATIONASSOCIATION._serialized_start=3500
  _CONFIGURATIONASSOCIATION._serialized_end=3689
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_redis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gcp/gcp_redis.proto\x12\x15oak9.tython.gcp.redis\x1a\x13shared/shared.proto\"\x83\x01\nARedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"\xc6\x01\n7RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\x12l\n\nstart_time\x18\x03 \x01(\x0b\x32X.oak9.tython.gcp.redis.RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime\"\xd3\x01\n\x1fRedisInstanceXMaintenancePolicy\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0bupdate_time\x18\x03 \x01(\t\x12q\n\x19weekly_maintenance_window\x18\x04 \x03(\x0b\x32N.oak9.tython.gcp.redis.RedisInstanceXMaintenancePolicyXWeeklyMaintenanceWindow\"i\n!RedisInstanceXMaintenanceSchedule\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x1e\n\x16schedule_deadline_time\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\t\"H\n\x16RedisInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8d\x0b\n\rRedisInstance\x12\x1f\n\x17\x61lternative_location_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61uth_enabled\x18\x02 \x01(\x08\x12\x13\n\x0b\x61uth_string\x18\x03 \x01(\t\x12\x1a\n\x12\x61uthorized_network\x18\x04 \x01(\t\x12\x14\n\x0c\x63onnect_mode\x18\x05 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x06 \x01(\t\x12\x1b\n\x13\x63urrent_location_id\x18\x07 \x01(\t\x12\x1c\n\x14\x63ustomer_managed_key\x18\x08 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\t \x01(\t\x12\x0c\n\x04host\x18\n \x01(\t\x12\n\n\x02id\x18\x0b \x01(\t\x12@\n\x06labels\x18\x0c \x03(\x0b\x32\x30.oak9.tython.gcp.redis.RedisInstance.LabelsEntry\x12\x13\n\x0blocation_id\x18\r \x01(\t\x12\x16\n\x0ememory_size_gb\x18\x0e \x01(\x01\x12\x0c\n\x04name\x18\x0f \x01(\t\x12>\n\x05nodes\x18\x10 \x03(\x0b\x32/.oak9.tython.gcp.redis.RedisInstance.NodesEntry\x12 \n\x18persistence_iam_identity\x18\x11 \x01(\t\x12\x0c\n\x04port\x18\x12 \x01(\x01\x12\x0f\n\x07project\x18\x13 \x01(\t\x12\x15\n\rread_endpoint\x18\x14 \x01(\t\x12\x1a\n\x12read_endpoint_port\x18\x15 \x01(\x01\x12\x1a\n\x12read_replicas_mode\x18\x16 \x01(\t\x12M\n\rredis_configs\x18\x17 \x03(\x0b\x32\x36.oak9.tython.gcp.redis.RedisInstance.RedisConfigsEntry\x12\x15\n\rredis_version\x18\x18 \x01(\t\x12\x0e\n\x06region\x18\x19 \x01(\t\x12\x15\n\rreplica_count\x18\x1a \x01(\x01\x12\x19\n\x11reserved_ip_range\x18\x1b \x01(\t\x12\x1a\n\x12secondary_ip_range\x18\x1c \x01(\t\x12P\n\x0fserver_ca_certs\x18\x1d \x03(\x0b\x32\x37.oak9.tython.gcp.redis.RedisInstance.ServerCaCertsEntry\x12\x0c\n\x04tier\x18\x1e \x01(\t\x12\x1f\n\x17transit_encryption_mode\x18\x1f \x01(\t\x12R\n\x12maintenance_policy\x18  \x01(\x0b\x32\x36.oak9.tython.gcp.redis.RedisInstanceXMaintenancePolicy\x12V\n\x14maintenance_schedule\x18! \x01(\x0b\x32\x38.oak9.tython.gcp.redis.RedisInstanceXMaintenanceSchedule\x12?\n\x08timeouts\x18\" \x01(\x0b\x32-.oak9.tython.gcp.redis.RedisInstanceXTimeouts\x12\x37\n\rresource_info\x18# \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11RedisConfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12ServerCaCertsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_redis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REDISINSTANCE_LABELSENTRY._options = None
  _REDISINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _REDISINSTANCE_NODESENTRY._options = None
  _REDISINSTANCE_NODESENTRY._serialized_options = b'8\001'
  _REDISINSTANCE_REDISCONFIGSENTRY._options = None
  _REDISINSTANCE_REDISCONFIGSENTRY._serialized_options = b'8\001'
  _REDISINSTANCE_SERVERCACERTSENTRY._options = None
  _REDISINSTANCE_SERVERCACERTSENTRY._serialized_options = b'8\001'
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOWXSTARTTIME._serialized_start=68
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOWXSTARTTIME._serialized_end=199
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOW._serialized_start=202
  _REDISINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOW._serialized_end=400
  _REDISINSTANCEXMAINTENANCEPOLICY._serialized_start=403
  _REDISINSTANCEXMAINTENANCEPOLICY._serialized_end=614
  _REDISINSTANCEXMAINTENANCESCHEDULE._serialized_start=616
  _REDISINSTANCEXMAINTENANCESCHEDULE._serialized_end=721
  _REDISINSTANCEXTIMEOUTS._serialized_start=723
  _REDISINSTANCEXTIMEOUTS._serialized_end=795
  _REDISINSTANCE._serialized_start=798
  _REDISINSTANCE._serialized_end=2219
  _REDISINSTANCE_LABELSENTRY._serialized_start=2021
  _REDISINSTANCE_LABELSENTRY._serialized_end=2066
  _REDISINSTANCE_NODESENTRY._serialized_start=2068
  _REDISINSTANCE_NODESENTRY._serialized_end=2112
  _REDISINSTANCE_REDISCONFIGSENTRY._serialized_start=2114
  _REDISINSTANCE_REDISCONFIGSENTRY._serialized_end=2165
  _REDISINSTANCE_SERVERCACERTSENTRY._serialized_start=2167
  _REDISINSTANCE_SERVERCACERTSENTRY._serialized_end=2219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_opsworkscm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_opsworkscm.proto\x12\x1aoak9.tython.aws.opsworkscm\x1a\x13shared/shared.proto\"m\n\x15ServerEngineAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xec\x05\n\x06Server\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08key_pair\x18\x02 \x01(\t\x12\x16\n\x0e\x65ngine_version\x18\x03 \x01(\t\x12\x18\n\x10service_role_arn\x18\x04 \x01(\t\x12 \n\x18\x64isable_automated_backup\x18\x05 \x01(\x08\x12\x11\n\tbackup_id\x18\x06 \x01(\t\x12\x14\n\x0c\x65ngine_model\x18\x07 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x08 \x01(\t\x12#\n\x1b\x61ssociate_public_ip_address\x18\t \x01(\x08\x12\x1c\n\x14instance_profile_arn\x18\n \x01(\t\x12\x1a\n\x12\x63ustom_certificate\x18\x0b \x01(\t\x12\x1f\n\x17preferred_backup_window\x18\x0c \x01(\t\x12\x1a\n\x12security_group_ids\x18\r \x03(\t\x12\x12\n\nsubnet_ids\x18\x0e \x03(\t\x12\x15\n\rcustom_domain\x18\x0f \x01(\t\x12\x1a\n\x12\x63ustom_private_key\x18\x10 \x01(\t\x12\x13\n\x0bserver_name\x18\x11 \x01(\t\x12L\n\x11\x65ngine_attributes\x18\x12 \x03(\x0b\x32\x31.oak9.tython.aws.opsworkscm.ServerEngineAttribute\x12\x1e\n\x16\x62\x61\x63kup_retention_count\x18\x13 \x01(\x05\x12\x15\n\rinstance_type\x18\x14 \x01(\t\x12:\n\x04tags\x18\x15 \x03(\x0b\x32,.oak9.tython.aws.opsworkscm.Server.TagsEntry\x12\x0e\n\x06\x65ngine\x18\x16 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\nOpsWorksCM\x12\x32\n\x06server\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.opsworkscm.Serverb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_opsworkscm_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVER_TAGSENTRY._options = None
  _SERVER_TAGSENTRY._serialized_options = b'8\001'
  _SERVERENGINEATTRIBUTE._serialized_start=77
  _SERVERENGINEATTRIBUTE._serialized_end=186
  _SERVER._serialized_start=189
  _SERVER._serialized_end=937
  _SERVER_TAGSENTRY._serialized_start=894
  _SERVER_TAGSENTRY._serialized_end=937
  _OPSWORKSCM._serialized_start=939
  _OPSWORKSCM._serialized_end=1003
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_service.proto\x12\x17oak9.tython.gcp.service\x1a\x13shared/shared.proto\")\n\x17ServiceAccountXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\"\xab\x02\n\x0eServiceAccount\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\r\n\x05\x65mail\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tunique_id\x18\t \x01(\t\x12\x42\n\x08timeouts\x18\n \x01(\x0b\x32\x30.oak9.tython.gcp.service.ServiceAccountXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"ServiceAccountIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf8\x01\n\x18ServiceAccountIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12N\n\tcondition\x18\x06 \x01(\x0b\x32;.oak9.tython.gcp.service.ServiceAccountIamBindingXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"[\n!ServiceAccountIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf5\x01\n\x17ServiceAccountIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\x12M\n\tcondition\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.service.ServiceAccountIamMemberXCondition\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\x17ServiceAccountIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x03\n\x11ServiceAccountKey\x12\n\n\x02id\x18\x01 \x01(\t\x12H\n\x07keepers\x18\x02 \x03(\x0b\x32\x37.oak9.tython.gcp.service.ServiceAccountKey.KeepersEntry\x12\x15\n\rkey_algorithm\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0bprivate_key\x18\x05 \x01(\t\x12\x18\n\x10private_key_type\x18\x06 \x01(\t\x12\x12\n\npublic_key\x18\x07 \x01(\t\x12\x17\n\x0fpublic_key_data\x18\x08 \x01(\t\x12\x17\n\x0fpublic_key_type\x18\t \x01(\t\x12\x1a\n\x12service_account_id\x18\n \x01(\t\x12\x13\n\x0bvalid_after\x18\x0b \x01(\t\x12\x14\n\x0cvalid_before\x18\x0c \x01(\t\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a.\n\x0cKeepersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n$ServiceNetworkingConnectionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x87\x02\n\x1bServiceNetworkingConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07peering\x18\x03 \x01(\t\x12\x1f\n\x17reserved_peering_ranges\x18\x04 \x03(\t\x12\x0f\n\x07service\x18\x05 \x01(\t\x12O\n\x08timeouts\x18\x06 \x01(\x0b\x32=.oak9.tython.gcp.service.ServiceNetworkingConnectionXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n)ServiceNetworkingPeeredDnsDomainXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\"\xa2\x02\n ServiceNetworkingPeeredDnsDomain\x12\x12\n\ndns_suffix\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0f\n\x07service\x18\x07 \x01(\t\x12T\n\x08timeouts\x18\x08 \x01(\x0b\x32\x42.oak9.tython.gcp.service.ServiceNetworkingPeeredDnsDomainXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVICEACCOUNTKEY_KEEPERSENTRY._options = None
  _SERVICEACCOUNTKEY_KEEPERSENTRY._serialized_options = b'8\001'
  _SERVICEACCOUNTXTIMEOUTS._serialized_start=71
  _SERVICEACCOUNTXTIMEOUTS._serialized_end=112
  _SERVICEACCOUNT._serialized_start=115
  _SERVICEACCOUNT._serialized_end=414
  _SERVICEACCOUNTIAMBINDINGXCONDITION._serialized_start=416
  _SERVICEACCOUNTIAMBINDINGXCONDITION._serialized_end=508
  _SERVICEACCOUNTIAMBINDING._serialized_start=511
  _SERVICEACCOUNTIAMBINDING._serialized_end=759
  _SERVICEACCOUNTIAMMEMBERXCONDITION._serialized_start=761
  _SERVICEACCOUNTIAMMEMBERXCONDITION._serialized_end=852
  _SERVICEACCOUNTIAMMEMBER._serialized_start=855
  _SERVICEACCOUNTIAMMEMBER._serialized_end=1100
  _SERVICEACCOUNTIAMPOLICY._serialized_start=1103
  _SERVICEACCOUNTIAMPOLICY._serialized_end=1260
  _SERVICEACCOUNTKEY._serialized_start=1263
  _SERVICEACCOUNTKEY._serialized_end=1698
  _SERVICEACCOUNTKEY_KEEPERSENTRY._serialized_start=1652
  _SERVICEACCOUNTKEY_KEEPERSENTRY._serialized_end=1698
  _SERVICENETWORKINGCONNECTIONXTIMEOUTS._serialized_start=1700
  _SERVICENETWORKINGCONNECTIONXTIMEOUTS._serialized_end=1786
  _SERVICENETWORKINGCONNECTION._serialized_start=1789
  _SERVICENETWORKINGCONNECTION._serialized_end=2052
  _SERVICENETWORKINGPEEREDDNSDOMAINXTIMEOUTS._serialized_start=2054
  _SERVICENETWORKINGPEEREDDNSDOMAINXTIMEOUTS._serialized_end=2143
  _SERVICENETWORKINGPEEREDDNSDOMAIN._serialized_start=2146
  _SERVICENETWORKINGPEEREDDNSDOMAIN._serialized_end=2436
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_applicationinsights.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!aws/aws_applicationinsights.proto\x12#oak9.tython.aws.applicationinsights\x1a\x13shared/shared.proto\"\x84\x01\n\x1a\x41pplicationCustomComponent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63omponent_name\x18\x02 \x01(\t\x12\x15\n\rresource_list\x18\x03 \x03(\t\"\x85\x01\n\x15\x41pplicationLogPattern\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cpattern_name\x18\x02 \x01(\t\x12\x0f\n\x07pattern\x18\x03 \x01(\t\x12\x0c\n\x04rank\x18\x04 \x01(\x05\"\xbf\x01\n\x18\x41pplicationLogPatternSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10pattern_set_name\x18\x02 \x01(\t\x12P\n\x0clog_patterns\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.applicationinsights.ApplicationLogPattern\"l\n\x16\x41pplicationAlarmMetric\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61larm_metric_name\x18\x02 \x01(\t\"\xac\x01\n\x0e\x41pplicationLog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x10\n\x08log_path\x18\x03 \x01(\t\x12\x10\n\x08log_type\x18\x04 \x01(\t\x12\x10\n\x08\x65ncoding\x18\x05 \x01(\t\x12\x13\n\x0bpattern_set\x18\x06 \x01(\t\"\xa9\x01\n\x17\x41pplicationWindowsEvent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0elog_group_name\x18\x02 \x01(\t\x12\x12\n\nevent_name\x18\x03 \x01(\t\x12\x14\n\x0c\x65vent_levels\x18\x04 \x03(\t\x12\x13\n\x0bpattern_set\x18\x05 \x01(\t\"q\n\x10\x41pplicationAlarm\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nalarm_name\x18\x02 \x01(\t\x12\x10\n\x08severity\x18\x03 \x01(\t\"\x8e\x03\n\x1f\x41pplicationConfigurationDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\ralarm_metrics\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.applicationinsights.ApplicationAlarmMetric\x12\x41\n\x04logs\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.applicationinsights.ApplicationLog\x12T\n\x0ewindows_events\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.applicationinsights.ApplicationWindowsEvent\x12\x45\n\x06\x61larms\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.applicationinsights.ApplicationAlarm\"\xd3\x02\n+ApplicationSubComponentConfigurationDetails\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\ralarm_metrics\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.applicationinsights.ApplicationAlarmMetric\x12\x41\n\x04logs\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.applicationinsights.ApplicationLog\x12T\n\x0ewindows_events\x18\x04 \x03(\x0b\x32<.oak9.tython.aws.applicationinsights.ApplicationWindowsEvent\"\xfe\x01\n(ApplicationSubComponentTypeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12sub_component_type\x18\x02 \x01(\t\x12}\n#sub_component_configuration_details\x18\x03 \x01(\x0b\x32P.oak9.tython.aws.applicationinsights.ApplicationSubComponentConfigurationDetails\"\xbb\x02\n!ApplicationComponentConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x63\n\x15\x63onfiguration_details\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.applicationinsights.ApplicationConfigurationDetails\x12x\n!sub_component_type_configurations\x18\x03 \x03(\x0b\x32M.oak9.tython.aws.applicationinsights.ApplicationSubComponentTypeConfiguration\"\xae\x03\n%ApplicationComponentMonitoringSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63omponent_name\x18\x02 \x01(\t\x12\x15\n\rcomponent_arn\x18\x03 \x01(\t\x12\x0c\n\x04tier\x18\x04 \x01(\t\x12$\n\x1c\x63omponent_configuration_mode\x18\x05 \x01(\t\x12y\n)default_overwrite_component_configuration\x18\x06 \x01(\x0b\x32\x46.oak9.tython.aws.applicationinsights.ApplicationComponentConfiguration\x12n\n\x1e\x63ustom_component_configuration\x18\x07 \x01(\x0b\x32\x46.oak9.tython.aws.applicationinsights.ApplicationComponentConfiguration\"\xff\x04\n\x0b\x41pplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13resource_group_name\x18\x02 \x01(\t\x12\x1b\n\x13\x63we_monitor_enabled\x18\x03 \x01(\x08\x12\x1a\n\x12ops_center_enabled\x18\x04 \x01(\x08\x12\x1e\n\x16ops_item_sns_topic_arn\x18\x05 \x01(\t\x12H\n\x04tags\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.applicationinsights.Application.TagsEntry\x12Z\n\x11\x63ustom_components\x18\x07 \x03(\x0b\x32?.oak9.tython.aws.applicationinsights.ApplicationCustomComponent\x12W\n\x10log_pattern_sets\x18\x08 \x03(\x0b\x32=.oak9.tython.aws.applicationinsights.ApplicationLogPatternSet\x12\"\n\x1a\x61uto_configuration_enabled\x18\t \x01(\x08\x12q\n\x1d\x63omponent_monitoring_settings\x18\n \x03(\x0b\x32J.oak9.tython.aws.applicationinsights.ApplicationComponentMonitoringSetting\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x13\x41pplicationInsights\x12\x45\n\x0b\x61pplication\x18\x01 \x03(\x0b\x32\x30.oak9.tython.aws.applicationinsights.Applicationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_applicationinsights_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPLICATION_TAGSENTRY._options = None
  _APPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _APPLICATIONCUSTOMCOMPONENT._serialized_start=96
  _APPLICATIONCUSTOMCOMPONENT._serialized_end=228
  _APPLICATIONLOGPATTERN._serialized_start=231
  _APPLICATIONLOGPATTERN._serialized_end=364
  _APPLICATIONLOGPATTERNSET._serialized_start=367
  _APPLICATIONLOGPATTERNSET._serialized_end=558
  _APPLICATIONALARMMETRIC._serialized_start=560
  _APPLICATIONALARMMETRIC._serialized_end=668
  _APPLICATIONLOG._serialized_start=671
  _APPLICATIONLOG._serialized_end=843
  _APPLICATIONWINDOWSEVENT._serialized_start=846
  _APPLICATIONWINDOWSEVENT._serialized_end=1015
  _APPLICATIONALARM._serialized_start=1017
  _APPLICATIONALARM._serialized_end=1130
  _APPLICATIONCONFIGURATIONDETAILS._serialized_start=1133
  _APPLICATIONCONFIGURATIONDETAILS._serialized_end=1531
  _APPLICATIONSUBCOMPONENTCONFIGURATIONDETAILS._serialized_start=1534
  _APPLICATIONSUBCOMPONENTCONFIGURATIONDETAILS._serialized_end=1873
  _APPLICATIONSUBCOMPONENTTYPECONFIGURATION._serialized_start=1876
  _APPLICATIONSUBCOMPONENTTYPECONFIGURATION._serialized_end=2130
  _APPLICATIONCOMPONENTCONFIGURATION._serialized_start=2133
  _APPLICATIONCOMPONENTCONFIGURATION._serialized_end=2448
  _APPLICATIONCOMPONENTMONITORINGSETTING._serialized_start=2451
  _APPLICATIONCOMPONENTMONITORINGSETTING._serialized_end=2881
  _APPLICATION._serialized_start=2884
  _APPLICATION._serialized_end=3523
  _APPLICATION_TAGSENTRY._serialized_start=3480
  _APPLICATION_TAGSENTRY._serialized_end=3523
  _APPLICATIONINSIGHTS._serialized_start=3525
  _APPLICATIONINSIGHTS._serialized_end=3617
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_ContainerRegistry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGISTRIES_FIELD_NUMBER: builtins.int
    @property
    def registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Registries]: ...
    def __init__(
        self,
        *,
        registries: collections.abc.Iterable[global___Registries] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["registries", b"registries"]) -> None: ...

global___Microsoft_ContainerRegistry = Microsoft_ContainerRegistry

@typing_extensions.final
class RegistriesWebhooks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CustomHeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    CUSTOM_HEADERS_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SERVICE_URI_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def custom_headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    scope: builtins.str
    service_uri: builtins.str
    status: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        actions: collections.abc.Iterable[builtins.str] | None = ...,
        custom_headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        scope: builtins.str = ...,
        service_uri: builtins.str = ...,
        status: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "custom_headers", b"custom_headers", "location", b"location", "name", b"name", "resource_info", b"resource_info", "scope", b"scope", "service_uri", b"service_uri", "status", b"status", "tags", b"tags"]) -> None: ...

global___RegistriesWebhooks = RegistriesWebhooks

@typing_extensions.final
class RegistriesTokens(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    SCOPE_MAP_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def credentials(self) -> global___TokenCredentialsProperties: ...
    scope_map_id: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        credentials: global___TokenCredentialsProperties | None = ...,
        scope_map_id: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "name", b"name", "resource_info", b"resource_info", "scope_map_id", b"scope_map_id", "status", b"status"]) -> None: ...

global___RegistriesTokens = RegistriesTokens

@typing_extensions.final
class TokenCredentialsProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATES_FIELD_NUMBER: builtins.int
    PASSWORDS_FIELD_NUMBER: builtins.int
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TokenCertificate]: ...
    @property
    def passwords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TokenPassword]: ...
    def __init__(
        self,
        *,
        certificates: collections.abc.Iterable[global___TokenCertificate] | None = ...,
        passwords: collections.abc.Iterable[global___TokenPassword] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificates", b"certificates", "passwords", b"passwords"]) -> None: ...

global___TokenCredentialsProperties = TokenCredentialsProperties

@typing_extensions.final
class TokenPassword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIME_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    creation_time: builtins.str
    expiry: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        creation_time: builtins.str = ...,
        expiry: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "expiry", b"expiry", "name", b"name"]) -> None: ...

global___TokenPassword = TokenPassword

@typing_extensions.final
class TokenCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCODED_PEM_CERTIFICATE_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    encoded_pem_certificate: builtins.str
    expiry: builtins.str
    name: builtins.str
    thumbprint: builtins.str
    def __init__(
        self,
        *,
        encoded_pem_certificate: builtins.str = ...,
        expiry: builtins.str = ...,
        name: builtins.str = ...,
        thumbprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encoded_pem_certificate", b"encoded_pem_certificate", "expiry", b"expiry", "name", b"name", "thumbprint", b"thumbprint"]) -> None: ...

global___TokenCertificate = TokenCertificate

@typing_extensions.final
class RegistriesScopeMaps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        actions: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions", b"actions", "description", b"description", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesScopeMaps = RegistriesScopeMaps

@typing_extensions.final
class RegistriesReplications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REGION_ENDPOINT_ENABLED_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANCY_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    location: builtins.str
    name: builtins.str
    region_endpoint_enabled: builtins.bool
    zone_redundancy: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        region_endpoint_enabled: builtins.bool = ...,
        zone_redundancy: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "region_endpoint_enabled", b"region_endpoint_enabled", "resource_info", b"resource_info", "tags", b"tags", "zone_redundancy", b"zone_redundancy"]) -> None: ...

global___RegistriesReplications = RegistriesReplications

@typing_extensions.final
class RegistriesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesPrivateEndpointConnections = RegistriesPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class RegistriesPipelineRuns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FORCE_UPDATE_TAG_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    force_update_tag: builtins.str
    @property
    def request(self) -> global___PipelineRunRequest: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        force_update_tag: builtins.str = ...,
        request: global___PipelineRunRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["request", b"request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["force_update_tag", b"force_update_tag", "name", b"name", "request", b"request", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesPipelineRuns = RegistriesPipelineRuns

@typing_extensions.final
class PipelineRunRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTS_FIELD_NUMBER: builtins.int
    CATALOG_DIGEST_FIELD_NUMBER: builtins.int
    PIPELINE_RESOURCE_ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    @property
    def artifacts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    catalog_digest: builtins.str
    pipeline_resource_id: builtins.str
    @property
    def source(self) -> global___PipelineRunSourceProperties: ...
    @property
    def target(self) -> global___PipelineRunTargetProperties: ...
    def __init__(
        self,
        *,
        artifacts: collections.abc.Iterable[builtins.str] | None = ...,
        catalog_digest: builtins.str = ...,
        pipeline_resource_id: builtins.str = ...,
        source: global___PipelineRunSourceProperties | None = ...,
        target: global___PipelineRunTargetProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source", b"source", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "catalog_digest", b"catalog_digest", "pipeline_resource_id", b"pipeline_resource_id", "source", b"source", "target", b"target"]) -> None: ...

global___PipelineRunRequest = PipelineRunRequest

@typing_extensions.final
class PipelineRunTargetProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___PipelineRunTargetProperties = PipelineRunTargetProperties

@typing_extensions.final
class PipelineRunSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___PipelineRunSourceProperties = PipelineRunSourceProperties

@typing_extensions.final
class RegistriesImportPipelines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityProperties: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source(self) -> global___ImportPipelineSourceProperties: ...
    @property
    def trigger(self) -> global___PipelineTriggerProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityProperties | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: collections.abc.Iterable[builtins.str] | None = ...,
        source: global___ImportPipelineSourceProperties | None = ...,
        trigger: global___PipelineTriggerProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "source", b"source", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource_info", b"resource_info", "source", b"source", "trigger", b"trigger"]) -> None: ...

global___RegistriesImportPipelines = RegistriesImportPipelines

@typing_extensions.final
class PipelineTriggerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def source_trigger(self) -> global___PipelineSourceTriggerProperties: ...
    def __init__(
        self,
        *,
        source_trigger: global___PipelineSourceTriggerProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_trigger", b"source_trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_trigger", b"source_trigger"]) -> None: ...

global___PipelineTriggerProperties = PipelineTriggerProperties

@typing_extensions.final
class PipelineSourceTriggerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___PipelineSourceTriggerProperties = PipelineSourceTriggerProperties

@typing_extensions.final
class ImportPipelineSourceProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    key_vault_uri: builtins.str
    type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        key_vault_uri: builtins.str = ...,
        type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_uri", b"key_vault_uri", "type", b"type", "uri", b"uri"]) -> None: ...

global___ImportPipelineSourceProperties = ImportPipelineSourceProperties

@typing_extensions.final
class RegistriesExportPipelines(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityProperties: ...
    location: builtins.str
    name: builtins.str
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def target(self) -> global___ExportPipelineTargetProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityProperties | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        options: collections.abc.Iterable[builtins.str] | None = ...,
        target: global___ExportPipelineTargetProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "options", b"options", "resource_info", b"resource_info", "target", b"target"]) -> None: ...

global___RegistriesExportPipelines = RegistriesExportPipelines

@typing_extensions.final
class ExportPipelineTargetProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_URI_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    key_vault_uri: builtins.str
    type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        key_vault_uri: builtins.str = ...,
        type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_uri", b"key_vault_uri", "type", b"type", "uri", b"uri"]) -> None: ...

global___ExportPipelineTargetProperties = ExportPipelineTargetProperties

@typing_extensions.final
class RegistriesConnectedRegistries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLIENT_TOKEN_IDS_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    LOGIN_SERVER_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_LIST_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def client_token_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def logging(self) -> global___LoggingProperties: ...
    @property
    def login_server(self) -> global___LoginServerProperties: ...
    mode: builtins.str
    @property
    def notifications_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def parent(self) -> global___ParentProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        client_token_ids: collections.abc.Iterable[builtins.str] | None = ...,
        logging: global___LoggingProperties | None = ...,
        login_server: global___LoginServerProperties | None = ...,
        mode: builtins.str = ...,
        notifications_list: collections.abc.Iterable[builtins.str] | None = ...,
        parent: global___ParentProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging", b"logging", "login_server", b"login_server", "parent", b"parent", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_token_ids", b"client_token_ids", "logging", b"logging", "login_server", b"login_server", "mode", b"mode", "name", b"name", "notifications_list", b"notifications_list", "parent", b"parent", "resource_info", b"resource_info"]) -> None: ...

global___RegistriesConnectedRegistries = RegistriesConnectedRegistries

@typing_extensions.final
class ParentProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    SYNC_PROPERTIES_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def sync_properties(self) -> global___SyncProperties: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        sync_properties: global___SyncProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sync_properties", b"sync_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "sync_properties", b"sync_properties"]) -> None: ...

global___ParentProperties = ParentProperties

@typing_extensions.final
class SyncProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_TTL_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    SYNC_WINDOW_FIELD_NUMBER: builtins.int
    TOKEN_ID_FIELD_NUMBER: builtins.int
    message_ttl: builtins.str
    schedule: builtins.str
    sync_window: builtins.str
    token_id: builtins.str
    def __init__(
        self,
        *,
        message_ttl: builtins.str = ...,
        schedule: builtins.str = ...,
        sync_window: builtins.str = ...,
        token_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_ttl", b"message_ttl", "schedule", b"schedule", "sync_window", b"sync_window", "token_id", b"token_id"]) -> None: ...

global___SyncProperties = SyncProperties

@typing_extensions.final
class LoginServerProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___LoginServerProperties = LoginServerProperties

@typing_extensions.final
class LoggingProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIT_LOG_STATUS_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    audit_log_status: builtins.str
    log_level: builtins.str
    def __init__(
        self,
        *,
        audit_log_status: builtins.str = ...,
        log_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit_log_status", b"audit_log_status", "log_level", b"log_level"]) -> None: ...

global___LoggingProperties = LoggingProperties

@typing_extensions.final
class Registries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADMIN_USER_ENABLED_FIELD_NUMBER: builtins.int
    ANONYMOUS_PULL_ENABLED_FIELD_NUMBER: builtins.int
    DATA_ENDPOINT_ENABLED_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    NETWORK_RULE_BYPASS_OPTIONS_FIELD_NUMBER: builtins.int
    NETWORK_RULE_SET_FIELD_NUMBER: builtins.int
    POLICIES_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANCY_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    REGISTRIES_CONNECTED_REGISTRIES_FIELD_NUMBER: builtins.int
    REGISTRIES_EXPORT_PIPELINES_FIELD_NUMBER: builtins.int
    REGISTRIES_IMPORT_PIPELINES_FIELD_NUMBER: builtins.int
    REGISTRIES_PIPELINE_RUNS_FIELD_NUMBER: builtins.int
    REGISTRIES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    REGISTRIES_REPLICATIONS_FIELD_NUMBER: builtins.int
    REGISTRIES_SCOPE_MAPS_FIELD_NUMBER: builtins.int
    REGISTRIES_TOKENS_FIELD_NUMBER: builtins.int
    REGISTRIES_WEBHOOKS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityProperties: ...
    location: builtins.str
    name: builtins.str
    admin_user_enabled: builtins.bool
    anonymous_pull_enabled: builtins.bool
    data_endpoint_enabled: builtins.bool
    @property
    def encryption(self) -> global___EncryptionProperty: ...
    network_rule_bypass_options: builtins.str
    @property
    def network_rule_set(self) -> global___NetworkRuleSet: ...
    @property
    def policies(self) -> global___Policies: ...
    public_network_access: builtins.str
    zone_redundancy: builtins.str
    @property
    def sku(self) -> global___Sku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def registries_connected_registries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesConnectedRegistries]: ...
    @property
    def registries_export_pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesExportPipelines]: ...
    @property
    def registries_import_pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesImportPipelines]: ...
    @property
    def registries_pipeline_runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesPipelineRuns]: ...
    @property
    def registries_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesPrivateEndpointConnections]: ...
    @property
    def registries_replications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesReplications]: ...
    @property
    def registries_scope_maps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesScopeMaps]: ...
    @property
    def registries_tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesTokens]: ...
    @property
    def registries_webhooks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RegistriesWebhooks]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityProperties | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        admin_user_enabled: builtins.bool = ...,
        anonymous_pull_enabled: builtins.bool = ...,
        data_endpoint_enabled: builtins.bool = ...,
        encryption: global___EncryptionProperty | None = ...,
        network_rule_bypass_options: builtins.str = ...,
        network_rule_set: global___NetworkRuleSet | None = ...,
        policies: global___Policies | None = ...,
        public_network_access: builtins.str = ...,
        zone_redundancy: builtins.str = ...,
        sku: global___Sku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        registries_connected_registries: collections.abc.Iterable[global___RegistriesConnectedRegistries] | None = ...,
        registries_export_pipelines: collections.abc.Iterable[global___RegistriesExportPipelines] | None = ...,
        registries_import_pipelines: collections.abc.Iterable[global___RegistriesImportPipelines] | None = ...,
        registries_pipeline_runs: collections.abc.Iterable[global___RegistriesPipelineRuns] | None = ...,
        registries_private_endpoint_connections: collections.abc.Iterable[global___RegistriesPrivateEndpointConnections] | None = ...,
        registries_replications: collections.abc.Iterable[global___RegistriesReplications] | None = ...,
        registries_scope_maps: collections.abc.Iterable[global___RegistriesScopeMaps] | None = ...,
        registries_tokens: collections.abc.Iterable[global___RegistriesTokens] | None = ...,
        registries_webhooks: collections.abc.Iterable[global___RegistriesWebhooks] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption", b"encryption", "identity", b"identity", "network_rule_set", b"network_rule_set", "policies", b"policies", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_user_enabled", b"admin_user_enabled", "anonymous_pull_enabled", b"anonymous_pull_enabled", "data_endpoint_enabled", b"data_endpoint_enabled", "encryption", b"encryption", "identity", b"identity", "location", b"location", "name", b"name", "network_rule_bypass_options", b"network_rule_bypass_options", "network_rule_set", b"network_rule_set", "policies", b"policies", "public_network_access", b"public_network_access", "registries_connected_registries", b"registries_connected_registries", "registries_export_pipelines", b"registries_export_pipelines", "registries_import_pipelines", b"registries_import_pipelines", "registries_pipeline_runs", b"registries_pipeline_runs", "registries_private_endpoint_connections", b"registries_private_endpoint_connections", "registries_replications", b"registries_replications", "registries_scope_maps", b"registries_scope_maps", "registries_tokens", b"registries_tokens", "registries_webhooks", b"registries_webhooks", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "zone_redundancy", b"zone_redundancy"]) -> None: ...

global___Registries = Registries

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class Policies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPORT_POLICY_FIELD_NUMBER: builtins.int
    QUARANTINE_POLICY_FIELD_NUMBER: builtins.int
    RETENTION_POLICY_FIELD_NUMBER: builtins.int
    TRUST_POLICY_FIELD_NUMBER: builtins.int
    @property
    def export_policy(self) -> global___ExportPolicy: ...
    @property
    def quarantine_policy(self) -> global___QuarantinePolicy: ...
    @property
    def retention_policy(self) -> global___RetentionPolicy: ...
    @property
    def trust_policy(self) -> global___TrustPolicy: ...
    def __init__(
        self,
        *,
        export_policy: global___ExportPolicy | None = ...,
        quarantine_policy: global___QuarantinePolicy | None = ...,
        retention_policy: global___RetentionPolicy | None = ...,
        trust_policy: global___TrustPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["export_policy", b"export_policy", "quarantine_policy", b"quarantine_policy", "retention_policy", b"retention_policy", "trust_policy", b"trust_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["export_policy", b"export_policy", "quarantine_policy", b"quarantine_policy", "retention_policy", b"retention_policy", "trust_policy", b"trust_policy"]) -> None: ...

global___Policies = Policies

@typing_extensions.final
class TrustPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    status: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status", "type", b"type"]) -> None: ...

global___TrustPolicy = TrustPolicy

@typing_extensions.final
class RetentionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    days: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        days: builtins.int = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["days", b"days", "status", b"status"]) -> None: ...

global___RetentionPolicy = RetentionPolicy

@typing_extensions.final
class QuarantinePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___QuarantinePolicy = QuarantinePolicy

@typing_extensions.final
class ExportPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___ExportPolicy = ExportPolicy

@typing_extensions.final
class NetworkRuleSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IPRule]: ...
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VirtualNetworkRule]: ...
    def __init__(
        self,
        *,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___IPRule] | None = ...,
        virtual_network_rules: collections.abc.Iterable[global___VirtualNetworkRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_action", b"default_action", "ip_rules", b"ip_rules", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___NetworkRuleSet = NetworkRuleSet

@typing_extensions.final
class VirtualNetworkRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    action: builtins.str
    id: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "id", b"id"]) -> None: ...

global___VirtualNetworkRule = VirtualNetworkRule

@typing_extensions.final
class IPRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    action: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "value", b"value"]) -> None: ...

global___IPRule = IPRule

@typing_extensions.final
class EncryptionProperty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_VAULT_PROPERTIES_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def key_vault_properties(self) -> global___KeyVaultProperties: ...
    status: builtins.str
    def __init__(
        self,
        *,
        key_vault_properties: global___KeyVaultProperties | None = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_vault_properties", b"key_vault_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_vault_properties", b"key_vault_properties", "status", b"status"]) -> None: ...

global___EncryptionProperty = EncryptionProperty

@typing_extensions.final
class KeyVaultProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    KEY_IDENTIFIER_FIELD_NUMBER: builtins.int
    identity: builtins.str
    key_identifier: builtins.str
    def __init__(
        self,
        *,
        identity: builtins.str = ...,
        key_identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "key_identifier", b"key_identifier"]) -> None: ...

global___KeyVaultProperties = KeyVaultProperties

@typing_extensions.final
class IdentityProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    principal_id: builtins.str
    tenant_id: builtins.str
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        principal_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["principal_id", b"principal_id", "tenant_id", b"tenant_id", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___IdentityProperties = IdentityProperties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cassandra.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_cassandra.proto\x12\x19oak9.tython.aws.cassandra\x1a\x13shared/shared.proto\"Z\n\x08Keyspace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rkeyspace_name\x18\x02 \x01(\t\"s\n\tCassandra\x12\x35\n\x08keyspace\x18\x01 \x03(\x0b\x32#.oak9.tython.aws.cassandra.Keyspace\x12/\n\x05table\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.cassandra.Table\"p\n\x0bTableColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63olumn_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63olumn_type\x18\x03 \x01(\t\"\x9d\x01\n\x18TableClusteringKeyColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x36\n\x06\x63olumn\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.cassandra.TableColumn\x12\x10\n\x08order_by\x18\x03 \x01(\t\"\x90\x01\n\x1aTableProvisionedThroughput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13read_capacity_units\x18\x02 \x01(\x05\x12\x1c\n\x14write_capacity_units\x18\x03 \x01(\x05\"\xb0\x01\n\x10TableBillingMode\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12U\n\x16provisioned_throughput\x18\x03 \x01(\x0b\x32\x35.oak9.tython.aws.cassandra.TableProvisionedThroughput\"\x8b\x03\n\x05Table\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rkeyspace_name\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12?\n\x0fregular_columns\x18\x04 \x03(\x0b\x32&.oak9.tython.aws.cassandra.TableColumn\x12\x45\n\x15partition_key_columns\x18\x05 \x03(\x0b\x32&.oak9.tython.aws.cassandra.TableColumn\x12S\n\x16\x63lustering_key_columns\x18\x06 \x03(\x0b\x32\x33.oak9.tython.aws.cassandra.TableClusteringKeyColumn\x12\x41\n\x0c\x62illing_mode\x18\x07 \x01(\x0b\x32+.oak9.tython.aws.cassandra.TableBillingModeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cassandra_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KEYSPACE._serialized_start=75
  _KEYSPACE._serialized_end=165
  _CASSANDRA._serialized_start=167
  _CASSANDRA._serialized_end=282
  _TABLECOLUMN._serialized_start=284
  _TABLECOLUMN._serialized_end=396
  _TABLECLUSTERINGKEYCOLUMN._serialized_start=399
  _TABLECLUSTERINGKEYCOLUMN._serialized_end=556
  _TABLEPROVISIONEDTHROUGHPUT._serialized_start=559
  _TABLEPROVISIONEDTHROUGHPUT._serialized_end=703
  _TABLEBILLINGMODE._serialized_start=706
  _TABLEBILLINGMODE._serialized_end=882
  _TABLE._serialized_start=885
  _TABLE._serialized_end=1280
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_shared.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_shared.proto\x12\x1eoak9.tython.gcp.compute_shared\x1a\x13shared/shared.proto\"F\n$ComputeSharedVpcHostProjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xcb\x01\n\x1b\x43omputeSharedVpcHostProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12V\n\x08timeouts\x18\x03 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_shared.ComputeSharedVpcHostProjectXTimeouts\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"I\n\'ComputeSharedVpcServiceProjectXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xef\x01\n\x1e\x43omputeSharedVpcServiceProject\x12\x14\n\x0chost_project\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x17\n\x0fservice_project\x18\x03 \x01(\t\x12Y\n\x08timeouts\x18\x04 \x01(\x0b\x32G.oak9.tython.gcp.compute_shared.ComputeSharedVpcServiceProjectXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_shared_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESHAREDVPCHOSTPROJECTXTIMEOUTS._serialized_start=85
  _COMPUTESHAREDVPCHOSTPROJECTXTIMEOUTS._serialized_end=155
  _COMPUTESHAREDVPCHOSTPROJECT._serialized_start=158
  _COMPUTESHAREDVPCHOSTPROJECT._serialized_end=361
  _COMPUTESHAREDVPCSERVICEPROJECTXTIMEOUTS._serialized_start=363
  _COMPUTESHAREDVPCSERVICEPROJECTXTIMEOUTS._serialized_end=436
  _COMPUTESHAREDVPCSERVICEPROJECT._serialized_start=439
  _COMPUTESHAREDVPCSERVICEPROJECT._serialized_end=678
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_qldb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61ws/aws_qldb.proto\x12\x14oak9.tython.aws.qldb\x1a\x13shared/shared.proto\"\xe9\x01\n\x06Ledger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10permissions_mode\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x03 \x01(\x08\x12\x34\n\x04tags\x18\x04 \x03(\x0b\x32&.oak9.tython.aws.qldb.Ledger.TagsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x04QLDB\x12,\n\x06ledger\x18\x01 \x01(\x0b\x32\x1c.oak9.tython.aws.qldb.Ledger\x12,\n\x06stream\x18\x02 \x03(\x0b\x32\x1c.oak9.tython.aws.qldb.Stream\"\x86\x01\n\x1aStreamKinesisConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nstream_arn\x18\x02 \x01(\t\x12\x1b\n\x13\x61ggregation_enabled\x18\x03 \x01(\x08\"\xeb\x02\n\x06Stream\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bledger_name\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x10\n\x08role_arn\x18\x04 \x01(\t\x12\x1c\n\x14inclusive_start_time\x18\x05 \x01(\t\x12\x1a\n\x12\x65xclusive_end_time\x18\x06 \x01(\t\x12O\n\x15kinesis_configuration\x18\x07 \x01(\x0b\x32\x30.oak9.tython.aws.qldb.StreamKinesisConfiguration\x12\x34\n\x04tags\x18\x08 \x03(\x0b\x32&.oak9.tython.aws.qldb.Stream.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_qldb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LEDGER_TAGSENTRY._options = None
  _LEDGER_TAGSENTRY._serialized_options = b'8\001'
  _STREAM_TAGSENTRY._options = None
  _STREAM_TAGSENTRY._serialized_options = b'8\001'
  _LEDGER._serialized_start=66
  _LEDGER._serialized_end=299
  _LEDGER_TAGSENTRY._serialized_start=256
  _LEDGER_TAGSENTRY._serialized_end=299
  _QLDB._serialized_start=301
  _QLDB._serialized_end=399
  _STREAMKINESISCONFIGURATION._serialized_start=402
  _STREAMKINESISCONFIGURATION._serialized_end=536
  _STREAM._serialized_start=539
  _STREAM._serialized_end=902
  _STREAM_TAGSENTRY._serialized_start=256
  _STREAM_TAGSENTRY._serialized_end=299
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_workflows.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_workflows.proto\x12\x19oak9.tython.gcp.workflows\x1a\x13shared/shared.proto\"L\n\x1aWorkflowsWorkflowXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf3\x03\n\x11WorkflowsWorkflow\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x38.oak9.tython.gcp.workflows.WorkflowsWorkflow.LabelsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0bname_prefix\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x13\n\x0brevision_id\x18\t \x01(\t\x12\x17\n\x0fservice_account\x18\n \x01(\t\x12\x17\n\x0fsource_contents\x18\x0b \x01(\t\x12\r\n\x05state\x18\x0c \x01(\t\x12\x13\n\x0bupdate_time\x18\r \x01(\t\x12G\n\x08timeouts\x18\x0e \x01(\x0b\x32\x35.oak9.tython.gcp.workflows.WorkflowsWorkflowXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_workflows_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKFLOWSWORKFLOW_LABELSENTRY._options = None
  _WORKFLOWSWORKFLOW_LABELSENTRY._serialized_options = b'8\001'
  _WORKFLOWSWORKFLOWXTIMEOUTS._serialized_start=75
  _WORKFLOWSWORKFLOWXTIMEOUTS._serialized_end=151
  _WORKFLOWSWORKFLOW._serialized_start=154
  _WORKFLOWSWORKFLOW._serialized_end=653
  _WORKFLOWSWORKFLOW_LABELSENTRY._serialized_start=608
  _WORKFLOWSWORKFLOW_LABELSENTRY._serialized_end=653
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_waf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_waf.proto\x12\x13oak9.tython.aws.waf\x1a\x13shared/shared.proto\"o\n\x18\x42yteMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"\x8d\x02\n\x1a\x42yteMatchSetByteMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.waf.ByteMatchSetFieldToMatch\x12\x1d\n\x15positional_constraint\x18\x03 \x01(\t\x12\x15\n\rtarget_string\x18\x04 \x01(\t\x12\x1c\n\x14target_string_base64\x18\x05 \x01(\t\x12\x1b\n\x13text_transformation\x18\x06 \x01(\t\"\xa1\x01\n\x0c\x42yteMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x11\x62yte_match_tuples\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.waf.ByteMatchSetByteMatchTuple\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x8f\x03\n\x03WAF\x12\x39\n\x0e\x62yte_match_set\x18\x01 \x03(\x0b\x32!.oak9.tython.aws.waf.ByteMatchSet\x12*\n\x06ip_set\x18\x02 \x03(\x0b\x32\x1a.oak9.tython.aws.waf.IPSet\x12\'\n\x04rule\x18\x03 \x03(\x0b\x32\x19.oak9.tython.aws.waf.Rule\x12\x43\n\x13size_constraint_set\x18\x04 \x03(\x0b\x32&.oak9.tython.aws.waf.SizeConstraintSet\x12J\n\x17sql_injection_match_set\x18\x05 \x03(\x0b\x32).oak9.tython.aws.waf.SqlInjectionMatchSet\x12.\n\tweb_a_c_l\x18\x06 \x01(\x0b\x32\x1b.oak9.tython.aws.waf.WebACL\x12\x37\n\rxss_match_set\x18\x07 \x03(\x0b\x32 .oak9.tython.aws.waf.XssMatchSet\"^\n\x14IPSetIPSetDescriptor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"\x95\x01\n\x05IPSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x12ip_set_descriptors\x18\x02 \x03(\x0b\x32).oak9.tython.aws.waf.IPSetIPSetDescriptor\x12\x0c\n\x04name\x18\x03 \x01(\t\"x\n\rRulePredicate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x64\x61ta_id\x18\x02 \x01(\t\x12\x0f\n\x07negated\x18\x03 \x01(\x08\x12\x0c\n\x04type\x18\x04 \x01(\t\"\x9a\x01\n\x04Rule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x36\n\npredicates\x18\x04 \x03(\x0b\x32\".oak9.tython.aws.waf.RulePredicate\"f\n\x1dSizeConstraintSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xfc\x01\n\x1fSizeConstraintSetSizeConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12J\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.waf.SizeConstraintSetFieldToMatch\x12\x0c\n\x04size\x18\x04 \x01(\x05\x12\x1b\n\x13text_transformation\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\"\xaa\x01\n\x11SizeConstraintSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x10size_constraints\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.waf.SizeConstraintSetSizeConstraint\"w\n SqlInjectionMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"\xd1\x01\n*SqlInjectionMatchSetSqlInjectionMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.waf.SqlInjectionMatchSetFieldToMatch\x12\x1b\n\x13text_transformation\x18\x03 \x01(\t\"\xc2\x01\n\x14SqlInjectionMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x63\n\x1asql_injection_match_tuples\x18\x03 \x03(\x0b\x32?.oak9.tython.aws.waf.SqlInjectionMatchSetSqlInjectionMatchTuple\"X\n\x0fWebACLWafAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\"\xa7\x01\n\x13WebACLActivatedRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x34\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.waf.WebACLWafAction\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12\x0f\n\x07rule_id\x18\x04 \x01(\t\"\xdb\x01\n\x06WebACL\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\x0b\x32$.oak9.tython.aws.waf.WebACLWafAction\x12\x13\n\x0bmetric_name\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x37\n\x05rules\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.waf.WebACLActivatedRule\"`\n\x17XssMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xb6\x01\n\x18XssMatchSetXssMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0e\x66ield_to_match\x18\x02 \x01(\x0b\x32,.oak9.tython.aws.waf.XssMatchSetFieldToMatch\x12\x1b\n\x13text_transformation\x18\x03 \x01(\t\"\x9d\x01\n\x0bXssMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12G\n\x10xss_match_tuples\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.waf.XssMatchSetXssMatchTupleb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_waf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BYTEMATCHSETFIELDTOMATCH._serialized_start=63
  _BYTEMATCHSETFIELDTOMATCH._serialized_end=174
  _BYTEMATCHSETBYTEMATCHTUPLE._serialized_start=177
  _BYTEMATCHSETBYTEMATCHTUPLE._serialized_end=446
  _BYTEMATCHSET._serialized_start=449
  _BYTEMATCHSET._serialized_end=610
  _WAF._serialized_start=613
  _WAF._serialized_end=1012
  _IPSETIPSETDESCRIPTOR._serialized_start=1014
  _IPSETIPSETDESCRIPTOR._serialized_end=1108
  _IPSET._serialized_start=1111
  _IPSET._serialized_end=1260
  _RULEPREDICATE._serialized_start=1262
  _RULEPREDICATE._serialized_end=1382
  _RULE._serialized_start=1385
  _RULE._serialized_end=1539
  _SIZECONSTRAINTSETFIELDTOMATCH._serialized_start=1541
  _SIZECONSTRAINTSETFIELDTOMATCH._serialized_end=1643
  _SIZECONSTRAINTSETSIZECONSTRAINT._serialized_start=1646
  _SIZECONSTRAINTSETSIZECONSTRAINT._serialized_end=1898
  _SIZECONSTRAINTSET._serialized_start=1901
  _SIZECONSTRAINTSET._serialized_end=2071
  _SQLINJECTIONMATCHSETFIELDTOMATCH._serialized_start=2073
  _SQLINJECTIONMATCHSETFIELDTOMATCH._serialized_end=2192
  _SQLINJECTIONMATCHSETSQLINJECTIONMATCHTUPLE._serialized_start=2195
  _SQLINJECTIONMATCHSETSQLINJECTIONMATCHTUPLE._serialized_end=2404
  _SQLINJECTIONMATCHSET._serialized_start=2407
  _SQLINJECTIONMATCHSET._serialized_end=2601
  _WEBACLWAFACTION._serialized_start=2603
  _WEBACLWAFACTION._serialized_end=2691
  _WEBACLACTIVATEDRULE._serialized_start=2694
  _WEBACLACTIVATEDRULE._serialized_end=2861
  _WEBACL._serialized_start=2864
  _WEBACL._serialized_end=3083
  _XSSMATCHSETFIELDTOMATCH._serialized_start=3085
  _XSSMATCHSETFIELDTOMATCH._serialized_end=3181
  _XSSMATCHSETXSSMATCHTUPLE._serialized_start=3184
  _XSSMATCHSETXSSMATCHTUPLE._serialized_end=3366
  _XSSMATCHSET._serialized_start=3369
  _XSSMATCHSET._serialized_end=3526
# @@protoc_insertion_point(module_scope)
